from sqlalchemy import *
from migrate import *
from dictionaries.versions import views_helper
import migrate.changeset

class Dictionaries(object):
    def __init__(self, meta):
        self.payforbiddance = Table('payforbiddance', meta,
            Column('valutcode', Integer, nullable=False, primary_key=True),
            Column('deptcode', Integer, nullable=False, primary_key=True),
        )

def getValutTables(meta):
    valut1 = Table('valut1', meta, autoload=True)
    valut2 = Table('valut2', meta, autoload=True)
    return [valut1, valut2]

def upgrade(migrate_engine):
    meta = MetaData(bind = migrate_engine)
    # add merchantid column to valut tables
    for tbl in getValutTables(meta):
        merchantid = Column('merchantid', Integer, nullable=True)
        if not 'merchantid' in tbl.columns:
            merchantid.create(tbl)
    views_helper.update_dic_view(migrate_engine, 'valut')

    # add map table of valutes and departments 
    table = Dictionaries(meta).payforbiddance
    basename = table.name
    for suffix in ['1','2']:
        table.name = basename+suffix
        if not table.exists():
            table.create()
    conn = migrate_engine.connect()
    conn.execute('create or replace view %s as select * from %s' % (basename, basename + '1'))


def downgrade(migrate_engine):
    #remove merchantid column from valut tables
    meta = MetaData(bind = migrate_engine)
    valut = views_helper.get_table_name(migrate_engine,'valut')
    for tbl in getValutTables(meta):
        if 'merchantid' in tbl.columns:
            tbl.c.merchantid.drop()
    views_helper.update_dic_view(migrate_engine, 'valut', valut)

    # add map table of valutes and departments
    table = Dictionaries(meta).payforbiddance
    basename = table.name
    for suffix in ['1','2']:
        table.name = basename+suffix
        if table.exists():
            table.drop()
    conn = migrate_engine.connect()
    
    conn.execute('drop view if exists %s' % (basename))
