from sqlalchemy import *
from migrate import *
import migrate.changeset

def getPayment(meta):
    payment = Table('paymentitem', meta,
                    Column('paymentitemid', Integer, nullable=False, primary_key=True, autoincrement=True),
                    Column('paymentid', String(100), nullable=False),
                    Column('creationtime', DateTime, nullable=False),
                    Column('accountnumber', String(200), nullable=False),
                    Column('amount', Numeric(precision=13, scale=2), nullable=False),
                    Column('commissionagent', Numeric(precision=13, scale=2), nullable=False),
                    Column('commissionsubagent', Numeric(precision=13, scale=2), nullable=False),
                    Column('terminalcode', String(100)),
                    Column('terminaladdress', String(255)),
                    Column('providercode', String(100), nullable=True),
                    Column('providername', String(100)),
                    Column('providerinn', String(100)),
                    Column('providerphone', String(100)),
                    Column('provideraddress', String(255)),
                    Column('categorycode', String(100), nullable=True),
                    Column('categoryname', String(255)),
                    Column('agentcode', String(100), nullable=True),
                    Column('agentname', String(255), nullable=True),
                    Column('agentinn', String(100), nullable=True),
                    Column('agentphone', String(100), nullable=True),
                    Column('agentaddress', String(100), nullable=True),
                    Column('subagentcode', String(100), nullable=True),
                    Column('subagentname', String(255), nullable=True),
                    Column('subagentinn', String(100), nullable=True),
                    Column('subagentphone', String(100), nullable=True),
                    Column('subagentaddress', String(100), nullable=True),
                    Column('cardnumber', String(200), nullable=True),
                    mysql_engine='InnoDB'
                    )
    return payment

def upgrade(migrate_engine):
    meta = MetaData(bind = migrate_engine)
    payment = getPayment(meta)
    payment.create()
    goodsitem = Table('goodsitem', meta, autoload=True)
    stornogoodsitem = Table('stornogoodsitem', meta, autoload=True)
    goodsitempaymentid = Column('paymentitemid', Integer, nullable=True)
    goodsitempaymentid.create(goodsitem)
    stornogoodsitempaymentid = Column('paymentitemid', Integer, nullable=True)
    stornogoodsitempaymentid.create(stornogoodsitem)
    migrate.changeset.constraint.ForeignKeyConstraint([goodsitem.c.paymentitemid], [payment.c.paymentitemid], name = 'goodsitempaymentitemidfk').create()
    migrate.changeset.constraint.ForeignKeyConstraint([stornogoodsitem.c.paymentitemid], [payment.c.paymentitemid], name = 'stornogoodsitempaymentitemidfk').create()

def downgrade(migrate_engine):
    meta = MetaData(bind = migrate_engine)
    payment = getPayment(meta)
    goodsitem = Table('goodsitem', meta, autoload=True)
    stornogoodsitem = Table('stornogoodsitem', meta, autoload=True)
    migrate.changeset.constraint.ForeignKeyConstraint([goodsitem.c.paymentitemid], [payment.c.paymentitemid], name = 'goodsitempaymentitemidfk').drop()
    migrate.changeset.constraint.ForeignKeyConstraint([stornogoodsitem.c.paymentitemid], [payment.c.paymentitemid], name = 'stornogoodsitempaymentitemidfk').drop()
    goodsitem.c.paymentitemid.drop()
    stornogoodsitem.c.paymentitemid.drop()
    payment.drop()
