# -*- coding: utf-8 -*-

from sqlalchemy import MetaData, Table, Column, Integer, String, Numeric, Boolean, ForeignKey, UniqueConstraint

def getKkmTable(meta):
    kkm = Table('kkm', meta,
        Column('kkmid', Integer, nullable = False, primary_key = True, autoincrement = True),
        Column('workshiftid', Integer, ForeignKey('workshift.workshiftid', name='kkmworkshiftidfk', ondelete = 'CASCADE'), nullable = False),
        Column('kkmnum', Integer, nullable = False),                        # Порядковый номер ККМ
        Column('producercode', Integer, nullable = False),                  # Код производителя ККМ
        Column('producername', String(100), nullable = False),              # Наименование производителя ККМ
        Column('modelnum', Integer, nullable = False),                      # Номер модели ККМ
        Column('modelname', String(100), nullable = False),                 # Наименование модели ККМ
        Column('serialnum', String(20), nullable = False),                  # Серийный номер ККМ
        Column('sumprotectedbeg', Numeric(precision = 13, scale = 2)),      # Необнуляемая сумма на начало смены
        Column('sumprotectedend', Numeric(precision = 13, scale = 2)),      # Необнуляемая сумма на конец смены
        Column('sumcashbeg', Numeric(precision = 13, scale = 2)),           # Наличность в кассе на начало смены
        Column('sumcashend', Numeric(precision = 13, scale = 2)),           # Наличность в кассе на конец смены
        Column('sumgain', Numeric(precision = 13, scale = 2)),              # Сумма выручки
        Column('countsale', Integer),                                       # Количество продаж
        Column('sumsale', Numeric(precision = 13, scale = 2)),              # Сумма продаж
        Column('sumsaleeklz', Numeric(precision = 13, scale = 2)),          # Сумма продаж из ЭКЛЗ
        Column('sumsalebypayment1', Numeric(precision = 13, scale = 2)),    # Сумма продаж по видам оплаты
        Column('sumsalebypayment2', Numeric(precision = 13, scale = 2)),
        Column('sumsalebypayment3', Numeric(precision = 13, scale = 2)),
        Column('sumsalebypayment4', Numeric(precision = 13, scale = 2)),
        Column('sumsalebypayment5', Numeric(precision = 13, scale = 2)),
        Column('sumsalebypayment6', Numeric(precision = 13, scale = 2)),
        Column('countback', Integer),                                       # Количество возвратов продаж
        Column('sumback', Numeric(precision = 13, scale = 2)),              # Сумма возвратов продаж
        Column('sumbackeklz', Numeric(precision = 13, scale = 2)),          # Сумма возвратов продаж из ЭКЛЗ
        Column('sumbackbypayment1', Numeric(precision = 13, scale = 2)),    # Сумма возвратов продаж по видам оплаты
        Column('sumbackbypayment2', Numeric(precision = 13, scale = 2)),
        Column('sumbackbypayment3', Numeric(precision = 13, scale = 2)),
        Column('sumbackbypayment4', Numeric(precision = 13, scale = 2)),
        Column('sumbackbypayment5', Numeric(precision = 13, scale = 2)),
        Column('sumbackbypayment6', Numeric(precision = 13, scale = 2)),
        Column('paymentname1', String(100)),                                # Наименования видов оплаты
        Column('paymentname2', String(100)),
        Column('paymentname3', String(100)),
        Column('paymentname4', String(100)),
        Column('paymentname5', String(100)),
        Column('paymentname6', String(100)),
        Column('summoneyin', Numeric(precision = 13, scale = 2)),           # Сумма внесений
        Column('countmoneyin', Integer),                                    # Количество внесений
        Column('summoneyout', Numeric(precision = 13, scale = 2)),          # Сумма выемов
        Column('countmoneyout', Integer),                                   # Количество выемов
        Column('crashed', Boolean, nullable = False),                       # Аварийное завершение (сломался 0-1)
        UniqueConstraint('kkmnum', 'workshiftid', name='kkmunique'), 

        mysql_engine='InnoDB'
    )
    return kkm

def upgrade(migrate_engine):

    meta = MetaData(bind = migrate_engine)
    
    Table('workshift', meta, autoload=True)
    
    table = getKkmTable(meta)
    if not table.exists():
        table.create();

def downgrade(migrate_engine):

    meta = MetaData(bind = migrate_engine)

    table = getKkmTable(meta)
    if table.exists():
        table.drop();
