#!/usr/bin/python3

import migrate.versioning.api as vers
import pymysql
import sys
import documents.versions.dump as dump
from artix.database.info import DBInfo

def databaseExists(cur, database):
    cur.execute("select schema_name from information_schema.schemata where schema_name = %s", [database])
    for _ in cur:
        return True
    return False

def createDatabaseIfNotExists(cur, database):
    if databaseExists(cur, database):
        sys.stdout.write("Database \033[1m%s\033[0;0m exists.\n" % database)
    else:
        sys.stdout.write('Creating database \033[1m%s\033[0;0m...' % database)
        cur.execute('create database if not exists %s default character set utf8' % database)
        sys.stdout.write("OK\n")

def addToVersionControl(url, repo):
    try:
        sys.stdout.write("Current \033[1m%s\033[0;0m version is \033[1m%d\033[0;0m\n" % (repo, vers.db_version(url, repo)))
    except Exception as e:
        sys.stdout.write("Putting \033[1m%s\033[0;0m under version control..." % repo)
        vers.version_control(url, repo)
        sys.stdout.write("OK\n")

def updateDatabaseVersion(url, repo):
    sys.stdout.write("Updating \033[1m%s\033[0;0m to version \033[1m%d\033[0;0m..." % (repo, vers.version(repo)))
    try:
        vers.upgrade(url, repo)
        sys.stdout.write("OK\n")
    except Exception as e:
        err = "\033[1mERROR\033[0;0m: %s\n" % e
        sys.stdout.write(err)
        dump.logError(err)


dbInfo = DBInfo()

if dbInfo.serverDb:
    print(u"Серверная БД, обновление не будет выполняться")
    exit(0)

print(u"Updating database with user %s@%s" % (dbInfo.user, dbInfo.host))

dictionaries = {'url': dbInfo.getUrl("dictionaries"), 'repo': 'dictionaries'}
documents = {'url': dbInfo.getUrl("documents"), 'repo': 'documents'}
queues = {'url': dbInfo.getUrl("queues"), 'repo': 'queues'}

conn = pymysql.connect(host=dbInfo.host, port=dbInfo.port, user=dbInfo.user, password=dbInfo.password)
cur = conn.cursor()
cur.execute('set names utf8')
createDatabaseIfNotExists(cur, 'documents')
createDatabaseIfNotExists(cur, 'dictionaries')
createDatabaseIfNotExists(cur, 'queues')
cur.close()
conn.close()

addToVersionControl(dictionaries['url'], dictionaries['repo'])
addToVersionControl(documents['url'], documents['repo'])
addToVersionControl(queues['url'], queues['repo'])

updateDatabaseVersion(dictionaries['url'], dictionaries['repo'])

version = vers.db_version(documents['url'], documents['repo'])
updateDatabaseVersion(documents['url'], documents['repo'])
updateDatabaseVersion(queues['url'], queues['repo'])

dump.restore()
